@@ -13,7 +13,7 @@ use constant DEFAULT_CONFIG => (
     bundling       => 1,
 );
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 my $TYPE_MAP = {
     'Bool'   => '!',
@@ -488,7 +488,7 @@ sub _parse_struct {
                 } keys %$value;
             }
             elsif (not ref $value) {
-                if (!$spec || $spec eq '!') {
+                if (!$spec || ($TYPE_MAP->{$spec} || $spec) eq '!') {
                     push @$default_args, "--$dest" if $value;
                 }
                 else {
